EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Packages_RecordPackageDelete',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records a delete record for the specified package, or removes the delete record if null is specified as the deleted date.'
GO

IF OBJECT_ID('[Packages_RecordPackageDelete]') IS NOT NULL DROP PROCEDURE [Packages_RecordPackageDelete]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [Packages_RecordPackageDelete]
(
	@Feed_Id INT,
	@Group_Name VARBINARY(200),
	@Package_Name VARBINARY(255),
	@Version_Text VARBINARY(200),
	@File_Type VARBINARY(20),
	@DeletedOn_Date DATETIME
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @DeletedOn_Date IS NOT NULL
	BEGIN
		IF EXISTS(SELECT * FROM [DeletedPackages] WITH (UPDLOCK, SERIALIZABLE) WHERE [Feed_Id] = @Feed_Id AND [Group_Name] = @Group_Name AND [Package_Name] = @Package_Name AND [Version_Text] = @Version_Text AND [File_Type] = @File_Type)
			UPDATE [DeletedPackages]
			   SET [DeletedOn_Date] = @DeletedOn_Date
			 WHERE [Feed_Id] = @Feed_Id
			   AND [Group_Name] = @Group_Name
			   AND [Package_Name] = @Package_Name
			   AND [Version_Text] = @Version_Text
			   AND [File_Type] = @File_Type

		ELSE
			INSERT INTO [DeletedPackages]
			(
				[Feed_Id],
				[Group_Name],
				[Package_Name],
				[Version_Text],
				[File_Type],
				[DeletedOn_Date]
			)
			VALUES
			(
				@Feed_Id,
				@Group_Name,
				@Package_Name,
				@Version_Text,
				@File_Type,
				@DeletedOn_Date
			)
	END
	ELSE
		DELETE
		  FROM [DeletedPackages]
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Group_Name] = @Group_Name
		   AND [Package_Name] = @Package_Name
		   AND [Version_Text] = @Version_Text
		   AND [File_Type] = @File_Type

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Packages_RecordPackageDelete] TO [ProGetUser_Role]
GO